<div class="row variablerow ignore">
    <div class="col-md-3 namecol">
        <p class="h4 pp-anchor" id="pp_var_{{ values['varname'] }}"><s>{{ values['varname'] }}</s><br/>
            <small>{{ vartype }}</small>
        </p>
    </div>