<tr class="{{ extra_class }}">
        <td class="fillremaining">{{ label }}</td>
        <td class="number">{{ count }}</td>
        <td class="number">{{ percentage }}%</td>
        <td>
            <div class="bar" style="width:{{ width }}%">&nbsp;</div>
        </td>
</tr>